@@ -19,7 +19,7 @@ import sys
 import time
 from calculate.lib.utils.files import getModeFile
 from calculate.lib.cl_ldap import ldapUser
-
+from calculate.lib.utils.common import ensure_unicode
 from calculate.lib.cl_lang import setLocalTranslate
 from functools import reduce
 
@@ -90,10 +90,10 @@ class _shareData(Printable):
         if self.getData() is False:
             return False
         else:
-            # self.data = filter(lambda x: x[0] != name, self.data)
             self.data = [x for x in self.data if x[0] != name]
             return True
 
+    @ensure_unicode
     def replace(self, name, listData):
         if self.getData() is False:
             return False
@@ -133,6 +133,7 @@ class passwd(_shareData):
     template = "%(login)s:x:%(uid)s:%(gid)s:%(gecos)s:%(directory)s:%(shell)s"
     lenData = 7
 
+    @ensure_unicode
     def add(self, name, uid, gid, gecos="", directory="", shell="/bin/bash"):
         if not directory:
             directory = "/home/%s" % name
@@ -157,6 +158,7 @@ class group(_shareData):
     template = "%(group_name)s:x:%(gid)s:%(user_list)s"
     lenData = 4
 
+    @ensure_unicode
     def add(self, name, gid, userList=()):
         groupData = self.template % {'group_name': name, 'gid': gid,
                                      'user_list': ','.join(userList)}
@@ -171,11 +173,11 @@ class group(_shareData):
                 self.data.append(groupList)
             return True
 
+    @ensure_unicode
     def replace(self, name, listData):
         if self.getData() is False:
             return False
         else:
-            # delEmpty = lambda y: filter(lambda x: x.strip(), y)
             delEmpty = lambda y: [x for x in y if x.strip()]
             flagFound = False
             for index, listDataOld in enumerate(self.data):
@@ -250,7 +252,8 @@ class shadow(_shareData):
     template = ("%(login)s:%(hash)s:%(shadowLastChange)s:"
                 "%(shadowMin)s:%(shadowMax)s:%(shadowWarning)s:::")
     lenData = 9
-
+    
+    @ensure_unicode
     def add(self, name, pwdHash,
             shadowLastChange=str(int(time.time() / 86400)), shadowMin="0",
             shadowMax="99999", shadowWarning="7"):
